From 25b26039854edf20b02bfd3dcb164fa15c77265d Mon Sep 17 00:00:00 2001
From: Amber Lin <Amber.Lin@amd.com>
Date: Thu, 21 Jul 2016 17:29:02 -0400
Subject: [PATCH 2/2] drm/amdgpu: Get user pages in non-current task

get_user_pages is changed to be called from current task where mm is being
operated on. get_user_pages_remote is introduced when the target mm is not
the current task's. Adjust amdgpu_ttm_tt_get_user_pages so it'll get user
pages in both cases.

Change-Id: I1214aacf9c47dfc5b4ec24b858efe769272fe2d6
Signed-off-by: Amber Lin <Amber.Lin@amd.com>
---
 drivers/gpu/drm/amd/amdgpu/amdgpu_ttm.c | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_ttm.c b/drivers/gpu/drm/amd/amdgpu/amdgpu_ttm.c
index b80d8d5..003d16b 100755
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_ttm.c
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_ttm.c
@@ -573,7 +573,11 @@ int amdgpu_ttm_tt_get_user_pages(struct ttm_tt *ttm, struct page **pages)
 		list_add(&guptask.list, &gtt->guptasks);
 		spin_unlock(&gtt->guptasklock);
 
-		r = get_user_pages(userptr, num_pages, write, 0, p, NULL);
+		if (gtt->usertask->mm == current->mm)
+			r = get_user_pages(userptr, num_pages, write, 0, p, NULL);
+		else
+			r = get_user_pages_remote(gtt->usertask, gtt->usertask->mm, userptr,
+				   num_pages, write, 0, p, NULL);
 
 		spin_lock(&gtt->guptasklock);
 		list_del(&guptask.list);
-- 
1.9.1

